<?php
/**
 * Plugin Name: Advanced Custom Accordions
 * Plugin URI: https://joevics.pro/advanced-custom-accordions
 * Description: Create beautiful, customizable accordions with 5 unique designs and shortcode support.
 * Version: 2.0.0
 * Requires at least: 5.2
 * Requires PHP: 7.4
 * Author: Victor Joshua
 * Author URI: https://joevics.pro
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: advanced-custom-accordions
 * Domain Path: /languages
 *
 * @package AdvancedCustomAccordions
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit;
}

// Define plugin constants
define('ACA_VERSION', '1.0.0');
define('ACA_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('ACA_PLUGIN_URL', plugin_dir_url(__FILE__));
define('ACA_PREFIX', 'aca_');

if (!class_exists('Advanced_Custom_Accordions')) {
    /**
     * Main plugin class
     */
    class Advanced_Custom_Accordions {
        /**
         * Instance of this class
         *
         * @var Advanced_Custom_Accordions
         */
        private static $instance = null;

        /**
         * Get an instance of this class
         *
         * @return Advanced_Custom_Accordions
         */
        public static function get_instance() {
            if (null === self::$instance) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        /**
         * Constructor
         */
        private function __construct() {
            // Initialize plugin
            add_action('plugins_loaded', array($this, 'init'));

            // Register activation and deactivation hooks
            register_activation_hook(__FILE__, array($this, 'activate'));
            register_deactivation_hook(__FILE__, array($this, 'deactivate'));
        }

        /**
         * Initialize plugin
         */
        public function init() {
            // Load text domain for internationalization
            $this->load_text_domain();

            // Include required files
            $this->include_files();

            // Initialize components
            $this->init_components();
        }

        /**
         * Load plugin text domain
         */
        private function load_text_domain() {
            load_plugin_textdomain(
                'advanced-custom-accordions',
                false,
                dirname(plugin_basename(__FILE__)) . '/languages/'
            );
        }

        /**
         * Include required files
         */
        private function include_files() {
            $files = array(
                'post-type' => 'includes/class-aca-post-type.php',
                'admin'     => 'includes/class-aca-admin.php',
                'metabox'   => 'includes/class-aca-metabox.php',
                'shortcode' => 'includes/class-aca-shortcode.php',
                'frontend'  => 'includes/class-aca-frontend.php',
                'helper'    => 'includes/class-aca-helper.php'
            );

            foreach ($files as $key => $file) {
                $file_path = ACA_PLUGIN_DIR . $file;
                if (file_exists($file_path)) {
                    require_once $file_path;
                } else {
                    // Log error or notify about missing file
                    error_log(sprintf(
                        'Advanced Custom Accordions: Required file %s is missing.',
                        $file
                    ));
                }
            }
        }

        /**
         * Initialize plugin components
         */
        private function init_components() {
            try {
                // Initialize post type if class exists
                if (class_exists('ACA_Post_Type')) {
                    new ACA_Post_Type();
                }

                // Initialize admin components if in admin area
                if (is_admin()) {
                    if (class_exists('ACA_Admin')) {
                        new ACA_Admin();
                    }
                    if (class_exists('ACA_Metabox')) {
                        new ACA_Metabox();
                    }
                }

                // Initialize frontend components
                if (class_exists('ACA_Frontend')) {
                    new ACA_Frontend();
                }
                if (class_exists('ACA_Shortcode')) {
                    new ACA_Shortcode();
                }

            } catch (Exception $e) {
                // Log initialization error
                error_log(sprintf(
                    'Advanced Custom Accordions: Error initializing components - %s',
                    $e->getMessage()
                ));
            }
        }

        /**
         * Activate plugin
         */
        public function activate() {
            // Create custom post type
            if (class_exists('ACA_Post_Type')) {
                $post_type = new ACA_Post_Type();
                $post_type->register_post_type();
            }

            // Flush rewrite rules
            flush_rewrite_rules();

            // Set default options
            $this->set_default_options();

            // Set version
            update_option('aca_version', ACA_VERSION);
        }

        /**
         * Set default options
         */
        private function set_default_options() {
            $default_options = array(
                'version' => ACA_VERSION,
                'accordion_styles' => array(
                    'classic',
                    'modern',
                    'material',
                    'elegant',
                    'bold'
                ),
                'default_style' => 'classic',
                'default_colors' => array(
                    'header_bg' => '#f4f4f4',
                    'header_text' => '#333333',
                    'content_bg' => '#ffffff',
                    'content_text' => '#666666',
                    'border_color' => '#dddddd'
                ),
                'animation_speed' => 300,
                'enable_preview' => true,
                'load_font_awesome' => false,
                'scroll_offset' => 100
            );

            // Only set options if they don't exist
            if (!get_option(ACA_PREFIX . 'settings')) {
                update_option(ACA_PREFIX . 'settings', $default_options);
            }
        }

        /**
         * Deactivate plugin
         */
        public function deactivate() {
            // Flush rewrite rules
            flush_rewrite_rules();
        }
    }
}

// Initialize plugin
function aca_init() {
    return Advanced_Custom_Accordions::get_instance();
}

// Start the plugin
aca_init();