(function($) {
    'use strict';

    class ACAFrontend {
        constructor(element) {
            this.$accordion = $(element);
            this.settings = this.$accordion.data('settings') || {};
            this.animationSpeed = parseInt(acaConfig.animationSpeed, 10) || 300;
            this.scrollOffset = parseInt(acaConfig.scrollOffset, 10) || 100;

            this.init();
        }

        /**
         * Initialize accordion
         */
        init() {
            this.bindEvents();
            this.initializeAria();

            // Open initial section if specified
            if (this.settings.initial_open >= 0) {
                const $initialSection = this.$accordion
                    .find('.aca-section')
                    .eq(this.settings.initial_open);
                
                if ($initialSection.length) {
                    this.openSection($initialSection, false);
                }
            }

            // Check URL hash for section
            this.checkUrlHash();
        }

        /**
         * Bind event listeners
         */
        bindEvents() {
            // Handle click events on accordion headers
            this.$accordion.on('click', '.aca-trigger', (e) => {
                e.preventDefault();
                const $section = $(e.currentTarget).closest('.aca-section');
                this.toggleSection($section);
            });

            // Handle keyboard navigation
            this.$accordion.on('keydown', '.aca-trigger', (e) => {
                const $target = $(e.currentTarget);
                const $section = $target.closest('.aca-section');
                
                switch (e.keyCode) {
                    case 13: // Enter
                    case 32: // Space
                        e.preventDefault();
                        this.toggleSection($section);
                        break;
                        
                    case 38: // Up arrow
                        e.preventDefault();
                        this.focusPreviousHeader($section);
                        break;
                        
                    case 40: // Down arrow
                        e.preventDefault();
                        this.focusNextHeader($section);
                        break;
                        
                    case 36: // Home
                        e.preventDefault();
                        this.focusFirstHeader();
                        break;
                        
                    case 35: // End
                        e.preventDefault();
                        this.focusLastHeader();
                        break;
                }
            });
        }

        /**
         * Initialize ARIA attributes
         */
        initializeAria() {
            this.$accordion.find('.aca-section').each((_, section) => {
                const $section = $(section);
                const $trigger = $section.find('.aca-trigger');
                const $content = $section.find('.aca-content');
                const sectionId = $section.attr('id') || `aca-section-${Math.random().toString(36).substr(2, 9)}`;
                
                // Set IDs if not present
                $section.attr('id', sectionId);
                $content.attr('id', `${sectionId}-content`);
                
                // Set ARIA attributes
                $trigger.attr({
                    'aria-controls': $content.attr('id'),
                    'aria-expanded': $section.hasClass('aca-active') ? 'true' : 'false'
                });
                
                $content.attr({
                    'role': 'region',
                    'aria-labelledby': $trigger.attr('id')
                });
            });
        }

        /**
         * Toggle accordion section
         * @param {jQuery} $section Section element
         */
        toggleSection($section) {
            const isOpen = $section.hasClass('aca-active');
            
            if (isOpen) {
                this.closeSection($section);
            } else {
                this.openSection($section);
            }
        }

        /**
         * Open accordion section
         * @param {jQuery} $section Section element
         * @param {boolean} animate Whether to animate
         */
        openSection($section, animate = true) {
            // Close other sections if collapse_others is enabled
            if (this.settings.collapse_others) {
                this.$accordion
                    .find('.aca-section.aca-active')
                    .not($section)
                    .each((_, section) => {
                        this.closeSection($(section));
                    });
            }

            const $trigger = $section.find('.aca-trigger');
            const $content = $section.find('.aca-content');

            // Update classes and attributes
            $section.addClass('aca-active');
            $trigger.attr('aria-expanded', 'true');
            
            // Show content
            if (animate) {
                $content
                    .slideDown(this.animationSpeed)
                    .removeAttr('hidden');
            } else {
                $content
                    .show()
                    .removeAttr('hidden');
            }

            // Scroll to section if enabled
            if (this.settings.scroll_to_top && animate) {
                this.scrollToSection($section);
            }

            // Trigger custom event
            this.$accordion.trigger('aca:sectionOpened', [$section]);
        }

        /**
         * Close accordion section
         * @param {jQuery} $section Section element
         */
        closeSection($section) {
            const $trigger = $section.find('.aca-trigger');
            const $content = $section.find('.aca-content');

            // Update classes and attributes
            $section.removeClass('aca-active');
            $trigger.attr('aria-expanded', 'false');
            
            // Hide content
            $content
                .slideUp(this.animationSpeed)
                .attr('hidden', '');

            // Trigger custom event
            this.$accordion.trigger('aca:sectionClosed', [$section]);
        }

        /**
         * Scroll to section
         * @param {jQuery} $section Section element
         */
        scrollToSection($section) {
            const offset = $section.offset().top - this.scrollOffset;
            $('html, body').animate({
                scrollTop: offset
            }, this.animationSpeed);
        }

        /**
         * Focus previous header
         * @param {jQuery} $currentSection Current section
         */
        focusPreviousHeader($currentSection) {
            const $prev = $currentSection.prev('.aca-section');
            if ($prev.length) {
                $prev.find('.aca-trigger').focus();
            } else {
                this.focusLastHeader();
            }
        }

        /**
         * Focus next header
         * @param {jQuery} $currentSection Current section
         */
        focusNextHeader($currentSection) {
            const $next = $currentSection.next('.aca-section');
            if ($next.length) {
                $next.find('.aca-trigger').focus();
            } else {
                this.focusFirstHeader();
            }
        }

        /**
         * Focus first header
         */
        focusFirstHeader() {
            this.$accordion
                .find('.aca-section:first .aca-trigger')
                .focus();
        }

        /**
         * Focus last header
         */
        focusLastHeader() {
            this.$accordion
                .find('.aca-section:last .aca-trigger')
                .focus();
        }

        /**
         * Check URL hash for section
         */
        checkUrlHash() {
            const hash = window.location.hash;
            if (hash) {
                const $section = this.$accordion.find(hash);
                if ($section.length) {
                    this.openSection($section);
                    setTimeout(() => {
                        this.scrollToSection($section);
                    }, 100);
                }
            }
        }
    }

    // Add to global scope for admin preview
    window.ACAFrontend = ACAFrontend;

    // Initialize all accordions on document ready
    $(document).ready(() => {
        $('.aca-accordion').each((_, element) => {
            new ACAFrontend(element);
        });
    });

})(jQuery);