(function($) {
    'use strict';

    // Initialize accordion admin functionality
    class ACAAdmin {
        constructor() {
            this.previewTimeout = null;
            this.initColorPickers();
            this.initSectionSorting();
            this.initSectionActions();
            this.initStylePreview();
            this.initLivePreview();
        }

        /**
         * Initialize color pickers
         */
        initColorPickers() {
            $('.aca-color-picker').wpColorPicker({
                change: debounce(() => {
                    this.updatePreview();
                }, 300)
            });
        }

        /**
         * Initialize section sorting
         */
        initSectionSorting() {
            $('.aca-sections-container').sortable({
                handle: '.aca-drag-handle',
                items: '.aca-section',
                axis: 'y',
                cursor: 'move',
                update: () => {
                    this.reindexSections();
                    this.updatePreview();
                }
            });
        }

        /**
         * Initialize section actions
         */
        initSectionActions() {
            // Top "Add Section" button
            $('#aca-add-section').on('click', (e) => {
                e.preventDefault();
                this.addSection(false);
            });

            // Bottom "Add Section" button
            $('#aca-add-section-bottom').on('click', (e) => {
                e.preventDefault();
                this.addSection(true);
            });

            // Remove section
            $(document).on('click', '.aca-remove-section', (e) => {
                e.preventDefault();
                if (confirm(acaAdmin.i18n.confirmDelete)) {
                    $(e.target).closest('.aca-section').remove();
                    this.reindexSections();
                    this.updatePreview();
                    this.checkSectionsEmpty();
                }
            });
        }

        /**
         * Initialize style preview
         */
        initStylePreview() {
            $('#aca_style').on('change', (e) => {
                const style = $(e.target).val();
                this.loadStylePreview(style);
                this.updatePreview(true);
            });
        }

        /**
         * Initialize live preview functionality
         */
        initLivePreview() {
            // TinyMCE editor changes
            if (typeof tinyMCE !== 'undefined') {
                tinyMCE.on('AddEditor', (e) => {
                    e.editor.on('change keyup', debounce(() => {
                        this.updatePreview();
                    }, 300));
                });
            }

            // Section title changes
            $(document).on('input', '.aca-section-title input', debounce(() => {
                this.updatePreview();
            }, 300));

            // Initial state checkbox changes
            $(document).on('change', 'input[name*="[initial_state]"]', () => {
                this.updatePreview();
            });

            // Settings changes
            $('.aca-settings-metabox input, .aca-settings-metabox select').on('change', () => {
                this.updatePreview();
            });

            // Manual refresh button
            $('#aca-refresh-preview').on('click', (e) => {
                e.preventDefault();
                this.updatePreview(true);
            });
        }

        /**
         * Add new accordion section
         * @param {boolean} scrollToNew Whether to scroll to the new section
         */
        addSection(scrollToNew = false) {
            const index = $('.aca-section').length;
            const template = wp.template('aca-section');
            const newSection = template({
                index: index,
                title: '',
                content: '',
                initial_state: false
            });

            $('.aca-sections-container').append(newSection);
            
            // Initialize WP editor for new section
            const editorId = `aca_section_content_${index}`;
            wp.editor.initialize(editorId, {
                tinymce: {
                    wpautop: true,
                    plugins: 'lists,paste,tabfocus,wordpress,wpeditimage,wpgallery,wplink',
                    toolbar1: 'formatselect,bold,italic,bullist,numlist,blockquote,alignleft,aligncenter,alignright,link,wp_more,spellchecker'
                },
                quicktags: true,
                mediaButtons: true
            });

            // Initialize color picker if present
            this.initColorPickers();
            
            // Show bottom button and hide empty message
            $('.aca-sections-empty').addClass('hidden');
            $('.aca-sections-bottom-toolbar').removeClass('hidden');
            
            // Scroll to new section if added from bottom button
            if (scrollToNew) {
                const $newSection = $('.aca-section').last();
                $('html, body').animate({
                    scrollTop: $newSection.offset().top - 50
                }, 500);
            }

            // Focus on the new section's title
            const $newTitle = $('.aca-section').last().find('.aca-section-title input');
            $newTitle.focus();
            
            this.updatePreview();
        }

        /**
         * Check if sections are empty
         */
        checkSectionsEmpty() {
            const isEmpty = $('.aca-section').length === 0;
            $('.aca-sections-bottom-toolbar').toggleClass('hidden', isEmpty);
            $('.aca-sections-empty').toggleClass('hidden', !isEmpty);
        }

        /**
         * Reindex sections after sorting
         */
        reindexSections() {
            $('.aca-section').each((index, element) => {
                const $section = $(element);
                $section.attr('data-index', index);
                
                // Update input names
                $section.find('input, textarea').each((_, input) => {
                    const $input = $(input);
                    const name = $input.attr('name');
                    if (name) {
                        $input.attr('name', name.replace(/\[\d+\]/, `[${index}]`));
                    }
                });

                // Update editor ID
                const $editor = $section.find('.wp-editor-area');
                if ($editor.length) {
                    const oldId = $editor.attr('id');
                    const newId = `aca_section_content_${index}`;
                    $editor.attr('id', newId);
                    $section.find('.wp-editor-wrap')
                        .attr('id', `wp-${newId}-wrap`)
                        .find('.wp-editor-tools')
                        .attr('id', `wp-${newId}-editor-tools`);
                }
            });
        }

        /**
         * Load style preview
         * @param {string} style Selected style
         */
        loadStylePreview(style) {
            const $preview = $('#aca-style-preview');
            $preview.attr('class', `aca-style-preview aca-style-${style}`);

            // Load default colors for selected style
            $.post(ajaxurl, {
                action: 'aca_get_style_defaults',
                style: style,
                nonce: acaAdmin.nonce
            }, (response) => {
                if (response.success && response.data) {
                    // Update color pickers
                    Object.entries(response.data).forEach(([key, value]) => {
                        $(`#aca_colors_${key}`).wpColorPicker('color', value);
                    });
                }
            });
        }

        /**
         * Update live preview
         * @param {boolean} showLoading Whether to show loading indicator
         */
        updatePreview(showLoading = false) {
            const $preview = $('#aca-accordion-preview');
            
            if (showLoading) {
                $preview.html('<div class="aca-preview-loading"><span class="spinner is-active"></span>' + acaAdmin.i18n.updating + '</div>');
            }

            clearTimeout(this.previewTimeout);
            this.previewTimeout = setTimeout(() => {
                const data = this.getAccordionData();

                $.ajax({
                    url: ajaxurl,
                    type: 'POST',
                    data: {
                        action: 'aca_get_preview',
                        data: data,
                        nonce: acaAdmin.nonce
                    },
                    success: (response) => {
                        if (response.success) {
                            $preview.html(response.data);
                            if (window.ACAFrontend) {
                                const accordion = $preview.find('.aca-accordion')[0];
                                if (accordion) {
                                    new window.ACAFrontend(accordion);
                                }
                            }
                        } else {
                            $preview.html('<div class="notice notice-error"><p>' + acaAdmin.i18n.previewError + '</p></div>');
                        }
                    },
                    error: () => {
                        $preview.html('<div class="notice notice-error"><p>' + acaAdmin.i18n.previewError + '</p></div>');
                    }
                });
            }, 300);
        }

        /**
         * Get current accordion data
         * @returns {Object} Accordion data
         */
        getAccordionData() {
            const data = {
                style: $('#aca_style').val(),
                colors: {},
                settings: {
                    collapse_others: $('#aca_settings_collapse_others').is(':checked'),
                    scroll_to_top: $('#aca_settings_scroll_to_top').is(':checked'),
                    initial_open: $('#aca_settings_initial_open').val()
                },
                sections: []
            };

            // Get colors
            $('.aca-color-picker').each((_, input) => {
                const $input = $(input);
                const key = $input.attr('id').replace('aca_colors_', '');
                data.colors[key] = $input.val();
            });

            // Get sections
            $('.aca-section').each((_, section) => {
                const $section = $(section);
                const editorId = $section.find('.wp-editor-area').attr('id');
                let content = '';

                if (typeof tinyMCE !== 'undefined' && tinyMCE.get(editorId)) {
                    content = tinyMCE.get(editorId).getContent();
                } else {
                    content = $section.find('.wp-editor-area').val();
                }

                data.sections.push({
                    title: $section.find('.aca-section-title input').val(),
                    content: content,
                    initial_state: $section.find('input[name*="[initial_state]"]').is(':checked')
                });
            });

            return data;
        }
    }

    // Helper function for debouncing
    function debounce(func, wait) {
        let timeout;
        return function executedFunction(...args) {
            const later = () => {
                timeout = null;
                func.apply(this, args);
            };
            clearTimeout(timeout);
            timeout = setTimeout(later, wait);
        };
    }

    // Initialize when document is ready
    $(document).ready(() => {
        new ACAAdmin();
    });

})(jQuery);