<?php
/**
 * Admin functionality for the accordion plugin
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Class ACA_Admin
 * Handles all admin-related functionality
 */
class ACA_Admin {
    private $default_settings = array(
        'enable_preview' => true,
        'load_font_awesome' => false,
        'animation_speed' => 300,
        'custom_css' => '',
        'scroll_offset' => 100,
        'disable_wrap_links' => false
    );

    /**
     * Constructor
     */
    public function __construct() {
        // Add admin menu items
        add_action('admin_menu', array($this, 'add_admin_menu'));
        
        // Register settings
        add_action('admin_init', array($this, 'register_settings'));
        
        // Enqueue admin scripts and styles
        add_action('admin_enqueue_scripts', array($this, 'enqueue_admin_assets'));
        
        // Add action links to plugins page
        add_filter('plugin_action_links_' . plugin_basename(ACA_PLUGIN_DIR . 'advanced-custom-accordions.php'), 
            array($this, 'add_plugin_action_links')
        );
        
        // Add row meta on plugins page
        add_filter('plugin_row_meta', array($this, 'add_plugin_row_meta'), 10, 2);

        // Add AJAX handlers
        add_action('wp_ajax_aca_get_preview', array($this, 'handle_preview_request'));
    }

    /**
     * Register plugin settings
     */
    public function register_settings() {
        register_setting(
            'aca_settings',
            ACA_PREFIX . 'settings',
            array(
                'type' => 'array',
                'description' => 'Advanced Custom Accordions plugin settings',
                'sanitize_callback' => array($this, 'sanitize_settings'),
                'default' => $this->default_settings
            )
        );

        // General Settings Section
        add_settings_section(
            'aca_general_settings',
            __('General Settings', 'advanced-custom-accordions'),
            null,
            'aca_settings'
        );

        // Enable Preview
        add_settings_field(
            'enable_preview',
            __('Enable Live Preview', 'advanced-custom-accordions'),
            array($this, 'render_checkbox_field'),
            'aca_settings',
            'aca_general_settings',
            array(
                'id' => 'enable_preview',
                'name' => 'enable_preview',
                'description' => __('Show live preview in accordion editor', 'advanced-custom-accordions')
            )
        );

        // Animation Speed
        add_settings_field(
            'animation_speed',
            __('Animation Speed', 'advanced-custom-accordions'),
            array($this, 'render_number_field'),
            'aca_settings',
            'aca_general_settings',
            array(
                'id' => 'animation_speed',
                'name' => 'animation_speed',
                'description' => __('Duration of opening/closing animations in milliseconds', 'advanced-custom-accordions'),
                'min' => 0,
                'max' => 2000,
                'step' => 50
            )
        );

        // Load Font Awesome
        add_settings_field(
            'load_font_awesome',
            __('Load Font Awesome', 'advanced-custom-accordions'),
            array($this, 'render_checkbox_field'),
            'aca_settings',
            'aca_general_settings',
            array(
                'id' => 'load_font_awesome',
                'name' => 'load_font_awesome',
                'description' => __('Load Font Awesome icons if your theme doesn\'t include them', 'advanced-custom-accordions')
            )
        );

        // Custom CSS
        add_settings_field(
            'custom_css',
            __('Custom CSS', 'advanced-custom-accordions'),
            array($this, 'render_textarea_field'),
            'aca_settings',
            'aca_general_settings',
            array(
                'id' => 'custom_css',
                'name' => 'custom_css',
                'description' => __('Add custom CSS styles for your accordions', 'advanced-custom-accordions')
            )
        );
    }

    /**
     * Sanitize settings
     */
    public function sanitize_settings($input) {
        if (!is_array($input)) {
            return $this->default_settings;
        }

        $sanitized = array();

        // Enable Preview
        $sanitized['enable_preview'] = !empty($input['enable_preview']);

        // Load Font Awesome
        $sanitized['load_font_awesome'] = !empty($input['load_font_awesome']);

        // Animation Speed
        $sanitized['animation_speed'] = isset($input['animation_speed']) 
            ? absint($input['animation_speed']) 
            : 300;

        if ($sanitized['animation_speed'] < 0) {
            $sanitized['animation_speed'] = 0;
        } elseif ($sanitized['animation_speed'] > 2000) {
            $sanitized['animation_speed'] = 2000;
        }

        // Custom CSS
        $sanitized['custom_css'] = isset($input['custom_css']) 
            ? wp_strip_all_tags($input['custom_css']) 
            : '';

        // Add error/update messages
        if ($sanitized['animation_speed'] !== absint($input['animation_speed'])) {
            add_settings_error(
                'aca_settings',
                'invalid_animation_speed',
                __('Animation speed must be between 0 and 2000 milliseconds.', 'advanced-custom-accordions'),
                'error'
            );
        }

        return $sanitized;
    }

    /**
     * Render checkbox field
     */
    public function render_checkbox_field($args) {
        $settings = get_option(ACA_PREFIX . 'settings', $this->default_settings);
        $value = isset($settings[$args['name']]) ? $settings[$args['name']] : false;
        ?>
        <label>
            <input type="checkbox" 
                   id="<?php echo esc_attr($args['id']); ?>"
                   name="<?php echo esc_attr(ACA_PREFIX . 'settings[' . $args['name'] . ']'); ?>"
                   value="1"
                   <?php checked($value); ?>>
            <?php echo esc_html($args['description']); ?>
        </label>
        <?php
    }

    /**
     * Render number field
     */
    public function render_number_field($args) {
        $settings = get_option(ACA_PREFIX . 'settings', $this->default_settings);
        $value = isset($settings[$args['name']]) ? $settings[$args['name']] : '';
        ?>
        <input type="number"
               id="<?php echo esc_attr($args['id']); ?>"
               name="<?php echo esc_attr(ACA_PREFIX . 'settings[' . $args['name'] . ']'); ?>"
               value="<?php echo esc_attr($value); ?>"
               min="<?php echo esc_attr($args['min']); ?>"
               max="<?php echo esc_attr($args['max']); ?>"
               step="<?php echo esc_attr($args['step']); ?>"
               class="small-text">
        <p class="description"><?php echo esc_html($args['description']); ?></p>
        <?php
    }

    /**
     * Add admin menu items
     */
    public function add_admin_menu() {
        // Add settings page under Accordions menu
        add_submenu_page(
            'edit.php?post_type=aca_accordion',
            __('Settings', 'advanced-custom-accordions'),
            __('Settings', 'advanced-custom-accordions'),
            'manage_options',
            'aca-settings',
            array($this, 'render_settings_page')
        );

        // Add help page
        add_submenu_page(
            'edit.php?post_type=aca_accordion',
            __('Help', 'advanced-custom-accordions'),
            __('Help', 'advanced-custom-accordions'),
            'manage_options',
            'aca-help',
            array($this, 'render_help_page')
        );
    }

    /**
     * Enqueue admin scripts and styles
     *
     * @param string $hook Current admin page hook
     */
    public function enqueue_admin_assets($hook) {
        $allowed_hooks = array(
            'post.php',
            'post-new.php',
            'aca_accordion_page_aca-settings'
        );

        // Only load on accordion post type pages and settings
        if (!in_array($hook, $allowed_hooks) || 
            (in_array($hook, array('post.php', 'post-new.php')) && 
             get_post_type() !== 'aca_accordion')) {
            return;
        }

        // Enqueue WordPress color picker
        wp_enqueue_style('wp-color-picker');
        
        // Admin styles
        wp_enqueue_style(
            'aca-admin-styles',
            ACA_PLUGIN_URL . 'assets/css/admin.css',
            array(),
            ACA_VERSION
        );

        // Admin scripts
        wp_enqueue_script(
            'aca-admin-script',
            ACA_PLUGIN_URL . 'assets/js/admin.js',
            array('jquery', 'wp-color-picker', 'jquery-ui-sortable'),
            ACA_VERSION,
            true
        );

        // Localize script
        wp_localize_script(
            'aca-admin-script',
            'acaAdmin',
            array(
                'ajaxUrl' => admin_url('admin-ajax.php'),
                'nonce' => wp_create_nonce('aca_admin_nonce'),
                'i18n' => array(
                    'confirmDelete' => __('Are you sure you want to delete this section?', 'advanced-custom-accordions'),
                    'addSection' => __('Add Section', 'advanced-custom-accordions'),
                    'saving' => __('Saving...', 'advanced-custom-accordions'),
                    'saved' => __('Saved!', 'advanced-custom-accordions'),
                    'error' => __('Error saving data.', 'advanced-custom-accordions'),
                    'updating' => __('Updating preview...', 'advanced-custom-accordions'),
                    'previewError' => __('Error updating preview.', 'advanced-custom-accordions')
                )
            )
        );
    }

    /**
     * Handle accordion preview AJAX request
     */
    public function handle_preview_request() {
        // Verify nonce
        if (!isset($_POST['nonce']) || !wp_verify_nonce($_POST['nonce'], 'aca_admin_nonce')) {
            wp_send_json_error(array('message' => __('Security check failed.', 'advanced-custom-accordions')));
        }

        // Verify user permissions
        if (!current_user_can('edit_posts')) {
            wp_send_json_error(array('message' => __('Permission denied.', 'advanced-custom-accordions')));
        }

        // Get and sanitize preview data
        $data = isset($_POST['data']) ? $this->sanitize_preview_data($_POST['data']) : array();
        if (empty($data)) {
            wp_send_json_error(array('message' => __('Invalid preview data.', 'advanced-custom-accordions')));
        }

        // Generate preview HTML
        $preview_html = $this->generate_preview_content($data);
        wp_send_json_success($preview_html);
    }

    /**
     * Sanitize preview data
     *
     * @param array $data Raw preview data
     * @return array Sanitized preview data
     */
    private function sanitize_preview_data($data) {
        if (!is_array($data)) {
            return array();
        }

        $sanitized = array();

        // Sanitize style
        $sanitized['style'] = isset($data['style']) ? sanitize_key($data['style']) : 'classic';

        // Sanitize colors
        $sanitized['colors'] = array();
        if (isset($data['colors']) && is_array($data['colors'])) {
            foreach ($data['colors'] as $key => $color) {
                $sanitized['colors'][sanitize_key($key)] = sanitize_hex_color($color);
            }
        }

        // Sanitize settings
        $sanitized['settings'] = array(
            'collapse_others' => !empty($data['settings']['collapse_others']),
            'scroll_to_top' => !empty($data['settings']['scroll_to_top']),
            'initial_open' => isset($data['settings']['initial_open']) ? 
                intval($data['settings']['initial_open']) : -1
        );

        // Sanitize sections
        $sanitized['sections'] = array();
        if (isset($data['sections']) && is_array($data['sections'])) {
            foreach ($data['sections'] as $section) {
                if (isset($section['title']) || isset($section['content'])) {
                    $sanitized['sections'][] = array(
                        'title' => isset($section['title']) ? 
                            sanitize_text_field($section['title']) : '',
                        'content' => isset($section['content']) ? 
                            wp_kses_post($section['content']) : '',
                        'initial_state' => !empty($section['initial_state'])
                    );
                }
            }
        }

        return $sanitized;
    }

    /**
     * Generate preview content
     *
     * @param array $data Sanitized preview data
     * @return string Generated HTML
     */
    private function generate_preview_content($data) {
        $preview_id = 'aca-preview-' . uniqid();

        ob_start();

        // Generate style tag with custom colors
        $custom_css = ACA_Frontend::generate_inline_styles($data['style'], $data['colors']);
        if (!empty($custom_css)) {
            echo '<style type="text/css">' . $custom_css . '</style>';
        }

        // Generate accordion markup
        $classes = array(
            'aca-accordion',
            'aca-style-' . $data['style'],
            $data['settings']['collapse_others'] ? 'aca-collapse-others' : ''
        );
        ?>
        <div id="<?php echo esc_attr($preview_id); ?>" 
             class="<?php echo esc_attr(implode(' ', array_filter($classes))); ?>"
             data-settings="<?php echo esc_attr(wp_json_encode($data['settings'])); ?>">
            <?php
            if (!empty($data['sections'])) {
                foreach ($data['sections'] as $index => $section) {
                    $section_id = $preview_id . '-section-' . $index;
                    $is_open = ($index === $data['settings']['initial_open']) || 
                              (!empty($section['initial_state']));
                    ?>
                    <div class="aca-section <?php echo $is_open ? 'aca-active' : ''; ?>"
                         id="<?php echo esc_attr($section_id); ?>">
                        <div class="aca-header">
                            <button class="aca-trigger"
                                    aria-expanded="<?php echo $is_open ? 'true' : 'false'; ?>"
                                    aria-controls="<?php echo esc_attr($section_id . '-content'); ?>">
                                <?php echo esc_html($section['title']); ?>
                                <span class="aca-icon"></span>
                            </button>
                        </div>
                        <div id="<?php echo esc_attr($section_id . '-content'); ?>"
                             class="aca-content"
                             role="region"
                             aria-labelledby="<?php echo esc_attr($section_id); ?>"
                             <?php if (!$is_open) : ?>hidden<?php endif; ?>>
                            <div class="aca-content-inner">
                                <?php echo wp_kses_post($section['content']); ?>
                            </div>
                        </div>
                    </div>
                    <?php
                }
            } else {
                ?>
                <div class="aca-empty-message">
                    <?php _e('Add sections to see the preview.', 'advanced-custom-accordions'); ?>
                </div>
                <?php
            }
            ?>
        </div>
        <?php

        return ob_get_clean();
    }

    /**
     * Add plugin action links
     *
     * @param array $links Existing plugin action links
     * @return array Modified plugin action links
     */
    public function add_plugin_action_links($links) {
        $custom_links = array(
            '<a href="' . admin_url('edit.php?post_type=aca_accordion&page=aca-settings') . '">' . 
                __('Settings', 'advanced-custom-accordions') . '</a>',
            '<a href="' . admin_url('edit.php?post_type=aca_accordion&page=aca-help') . '">' . 
                __('Help', 'advanced-custom-accordions') . '</a>'
        );
        
        return array_merge($custom_links, $links);
    }

    /**
     * Add plugin row meta
     *
     * @param array $links Existing plugin row meta
     * @param string $file Plugin base file
     * @return array Modified plugin row meta
     */
    public function add_plugin_row_meta($links, $file) {
        if (plugin_basename(ACA_PLUGIN_DIR . 'advanced-custom-accordions.php') === $file) {
            $row_meta = array(
                'docs' => '<a href="' . esc_url('https://yourwebsite.com/accordion-docs') . '" target="_blank">' . 
                    __('Documentation', 'advanced-custom-accordions') . '</a>',
                'support' => '<a href="' . esc_url('https://yourwebsite.com/support') . '" target="_blank">' . 
                    __('Support', 'advanced-custom-accordions') . '</a>'
            );

            return array_merge($links, $row_meta);
        }
        
        return $links;
    }

    /**
     * Render settings page
     */
    public function render_settings_page() {
        // Check user capabilities
        if (!current_user_can('manage_options')) {
            return;
        }

        ?>
        <div class="wrap">
            <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
            <?php settings_errors('aca_settings'); ?>
            <form action="options.php" method="post">
                <?php
                settings_fields('aca_settings');
                do_settings_sections('aca_settings');
                submit_button('Save Settings');
                ?>
            </form>
        </div>
        <?php
    }

    /**
     * Render textarea field
     */
    public function render_textarea_field($args) {
        $settings = get_option(ACA_PREFIX . 'settings', $this->default_settings);
        $value = isset($settings[$args['name']]) ? $settings[$args['name']] : '';
        ?>
        <textarea id="<?php echo esc_attr($args['id']); ?>"
                  name="<?php echo esc_attr(ACA_PREFIX . 'settings[' . $args['name'] . ']'); ?>"
                  rows="10"
                  class="large-text code"><?php echo esc_textarea($value); ?></textarea>
        <p class="description"><?php echo esc_html($args['description']); ?></p>
        <?php
    }


    /**
     * Save plugin settings
     */
    private function save_settings() {
        $settings = array(
            'enable_preview' => isset($_POST['enable_preview']),
            'load_font_awesome' => isset($_POST['load_font_awesome']),
            'custom_css' => isset($_POST['custom_css']) ? 
                wp_strip_all_tags($_POST['custom_css']) : '',
            'animation_speed' => isset($_POST['animation_speed']) ? 
                absint($_POST['animation_speed']) : 300
        );

        update_option(ACA_PREFIX . 'settings', $settings);
        add_settings_error(
            'aca_settings',
            'settings_updated',
            __('Settings saved successfully.', 'advanced-custom-accordions'),
            'updated'
        );
    }

    /**
     * Render help page
     */
    public function render_help_page() {
        // Check user capabilities
        if (!current_user_can('manage_options')) {
            return;
        }

        // Include help template
        require_once ACA_PLUGIN_DIR . 'admin/templates/help-page.php';
    }
}