<?php
/**
 * Frontend functionality for the accordion plugin
 *
 * @package AdvancedCustomAccordions
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Class ACA_Frontend
 * Handles all frontend-related functionality
 */
class ACA_Frontend {
    /**
     * Constructor
     */
    public function __construct() {
        // Register scripts and styles
        add_action('wp_enqueue_scripts', array($this, 'register_assets'));
        
        // Add custom CSS to header
        add_action('wp_head', array($this, 'add_custom_css'));
    }

    /**
     * Register frontend assets
     */
    public function register_assets() {
        // Register styles
        wp_register_style(
            'aca-accordion-style',
            ACA_PLUGIN_URL . 'assets/css/accordion.css',
            array(),
            ACA_VERSION
        );

        // Register scripts
        wp_register_script(
            'aca-accordion-script',
            ACA_PLUGIN_URL . 'assets/js/accordion.js',
            array('jquery'),
            ACA_VERSION,
            true
        );

        // Localize script
        wp_localize_script(
            'aca-accordion-script',
            'acaConfig',
            array(
                'scrollOffset' => apply_filters('aca_scroll_offset', 100),
                'animationSpeed' => apply_filters('aca_animation_speed', 300),
                'i18n' => array(
                    'expand' => __('Expand', 'advanced-custom-accordions'),
                    'collapse' => __('Collapse', 'advanced-custom-accordions')
                )
            )
        );
    }

    /**
     * Add custom CSS to header
     */
    public function add_custom_css() {
        // Get plugin settings
        $settings = get_option(ACA_PREFIX . 'settings');
        
        // Check if custom CSS exists
        if (!empty($settings['custom_css'])) {
            echo "\n<!-- Advanced Custom Accordions Custom CSS -->\n";
            echo "<style type='text/css'>\n";
            echo wp_strip_all_tags($settings['custom_css']) . "\n";
            echo "</style>\n";
        }
    }

    /**
     * Generate inline styles for an accordion
     *
     * @param string $style Accordion style
     * @param array $colors Color settings
     * @return string Generated CSS
     */
    public static function generate_inline_styles($style, $colors) {
        $css = '';
        
        // Base styles for all accordions
        $css .= "
            .aca-accordion .aca-trigger {
                background-color: {$colors['header_bg']};
                color: {$colors['header_text']};
            }
            .aca-accordion .aca-section.aca-active .aca-trigger {
                background-color: {$colors['header_bg_active']};
                color: {$colors['header_text_active']};
            }
            .aca-accordion .aca-content {
                background-color: {$colors['content_bg']};
                color: {$colors['content_text']};
                border-color: {$colors['border_color']};
            }
            .aca-accordion .aca-icon {
                border-color: {$colors['header_text']};
            }
            .aca-accordion .aca-section.aca-active .aca-icon {
                border-color: {$colors['header_text_active']};
            }
        ";
        
        // Style-specific styles
        switch ($style) {
            case 'modern':
                $css .= self::get_modern_styles($colors);
                break;
                
            case 'material':
                $css .= self::get_material_styles($colors);
                break;
                
            case 'elegant':
                $css .= self::get_elegant_styles($colors);
                break;
                
            case 'bold':
                $css .= self::get_bold_styles($colors);
                break;
        }
        
        return $css;
    }

    /**
     * Get modern style specific CSS
     *
     * @param array $colors Color settings
     * @return string CSS styles
     */
    private static function get_modern_styles($colors) {
        $rgb = self::hex_to_rgb($colors['header_bg']);
        return "
            .aca-style-modern .aca-trigger {
                border-radius: 8px;
                box-shadow: 0 2px 4px rgba(0,0,0,0.1);
                transition: all 0.3s ease;
            }
            .aca-style-modern .aca-section.aca-active .aca-trigger {
                border-radius: 8px 8px 0 0;
                box-shadow: 0 2px 4px rgba({$rgb['r']}, {$rgb['g']}, {$rgb['b']}, 0.2);
            }
            .aca-style-modern .aca-content {
                border-radius: 0 0 8px 8px;
                box-shadow: 0 2px 4px rgba(0,0,0,0.1);
                border: none;
            }
            .aca-style-modern .aca-icon {
                transition: transform 0.3s ease;
            }
            .aca-style-modern .aca-section.aca-active .aca-icon {
                transform: rotate(180deg);
            }
        ";
    }

    /**
     * Get material style specific CSS
     *
     * @param array $colors Color settings
     * @return string CSS styles
     */
    private static function get_material_styles($colors) {
        $rgb = self::hex_to_rgb($colors['header_bg']);
        return "
            .aca-style-material .aca-trigger {
                border-radius: 4px;
                transition: background-color 0.3s ease, box-shadow 0.3s ease;
                box-shadow: 0 1px 3px rgba(0,0,0,0.12);
            }
            .aca-style-material .aca-trigger:hover {
                background-color: rgba({$rgb['r']}, {$rgb['g']}, {$rgb['b']}, 0.9);
            }
            .aca-style-material .aca-section.aca-active .aca-trigger {
                box-shadow: 0 2px 5px rgba(0,0,0,0.2);
            }
            .aca-style-material .aca-content {
                border: none;
                box-shadow: 0 2px 5px rgba(0,0,0,0.1);
                border-radius: 0 0 4px 4px;
            }
            .aca-style-material .aca-icon {
                transition: transform 0.3s cubic-bezier(0.4, 0.0, 0.2, 1);
            }
            .aca-style-material .aca-section.aca-active .aca-icon {
                transform: rotate(180deg);
            }
        ";
    }

    /**
     * Get elegant style specific CSS
     *
     * @param array $colors Color settings
     * @return string CSS styles
     */
    private static function get_elegant_styles($colors) {
        return "
            .aca-style-elegant .aca-trigger {
                border: none;
                border-bottom: 1px solid {$colors['border_color']};
                padding: 20px 30px;
                font-family: Georgia, serif;
                transition: all 0.3s ease;
            }
            .aca-style-elegant .aca-section.aca-active .aca-trigger {
                border-bottom-color: transparent;
            }
            .aca-style-elegant .aca-content {
                border: none;
                border-bottom: 1px solid {$colors['border_color']};
                padding: 30px;
            }
            .aca-style-elegant .aca-icon {
                opacity: 0.6;
                transition: opacity 0.3s ease;
            }
            .aca-style-elegant .aca-trigger:hover .aca-icon {
                opacity: 1;
            }
        ";
    }

    /**
     * Get bold style specific CSS
     *
     * @param array $colors Color settings
     * @return string CSS styles
     */
    private static function get_bold_styles($colors) {
        return "
            .aca-style-bold .aca-section {
                border: 3px solid {$colors['border_color']};
                margin-bottom: 20px;
            }
            .aca-style-bold .aca-trigger {
                padding: 20px;
                font-weight: 700;
                text-transform: uppercase;
                letter-spacing: 1px;
            }
            .aca-style-bold .aca-content {
                border-top: 3px solid {$colors['border_color']};
            }
            .aca-style-bold .aca-icon {
                width: 24px;
                height: 24px;
            }
        ";
    }

    /**
     * Convert hex color to RGB
     *
     * @param string $hex Hex color code
     * @return array RGB values
     */
    private static function hex_to_rgb($hex) {
        $hex = str_replace('#', '', $hex);
        
        if (strlen($hex) === 3) {
            $hex = str_repeat(substr($hex, 0, 1), 2) . 
                   str_repeat(substr($hex, 1, 1), 2) . 
                   str_repeat(substr($hex, 2, 1), 2);
        }
        
        return array(
            'r' => hexdec(substr($hex, 0, 2)),
            'g' => hexdec(substr($hex, 2, 2)),
            'b' => hexdec(substr($hex, 4, 2))
        );
    }
}