<?php
/**
 * Helper functions for the accordion plugin
 *
 * @package AdvancedCustomAccordions
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Class ACA_Helper
 * Contains helper functions used throughout the plugin
 */
class ACA_Helper {
    /**
     * Get available accordion styles
     *
     * @return array Array of available styles
     */
    public static function get_accordion_styles() {
        return array(
            'classic' => array(
                'label' => __('Classic', 'advanced-custom-accordions'),
                'description' => __('Clean and professional design with smooth transitions', 'advanced-custom-accordions'),
                'preview_image' => ACA_PLUGIN_URL . 'assets/images/classic-preview.png'
            ),
            'modern' => array(
                'label' => __('Modern', 'advanced-custom-accordions'),
                'description' => __('Minimalist design with fade effects', 'advanced-custom-accordions'),
                'preview_image' => ACA_PLUGIN_URL . 'assets/images/modern-preview.png'
            ),
            'material' => array(
                'label' => __('Material', 'advanced-custom-accordions'),
                'description' => __('Material design inspired with ripple effects', 'advanced-custom-accordions'),
                'preview_image' => ACA_PLUGIN_URL . 'assets/images/material-preview.png'
            ),
            'elegant' => array(
                'label' => __('Elegant', 'advanced-custom-accordions'),
                'description' => __('Sophisticated design with gentle animations', 'advanced-custom-accordions'),
                'preview_image' => ACA_PLUGIN_URL . 'assets/images/elegant-preview.png'
            ),
            'bold' => array(
                'label' => __('Bold', 'advanced-custom-accordions'),
                'description' => __('High-contrast design with dynamic effects', 'advanced-custom-accordions'),
                'preview_image' => ACA_PLUGIN_URL . 'assets/images/bold-preview.png'
            )
        );
    }

    /**
     * Get default colors for accordion styles
     *
     * @param string $style Accordion style
     * @return array Array of default colors
     */
    public static function get_default_colors($style = 'classic') {
        $base_colors = array(
            'header_bg' => '#f4f4f4',
            'header_text' => '#333333',
            'header_bg_active' => '#e8e8e8',
            'header_text_active' => '#000000',
            'content_bg' => '#ffffff',
            'content_text' => '#666666',
            'border_color' => '#dddddd'
        );

        $style_colors = array(
            'classic' => array(),  // Uses base colors
            'modern' => array(
                'header_bg' => '#ffffff',
                'header_text' => '#2c3e50',
                'header_bg_active' => '#f8f9fa',
                'header_text_active' => '#1abc9c',
                'border_color' => '#e9ecef'
            ),
            'material' => array(
                'header_bg' => '#ffffff',
                'header_text' => '#212121',
                'header_bg_active' => '#f5f5f5',
                'header_text_active' => '#2196F3',
                'border_color' => '#eeeeee'
            ),
            'elegant' => array(
                'header_bg' => '#fafafa',
                'header_text' => '#2c3e50',
                'header_bg_active' => '#f5f5f5',
                'header_text_active' => '#8e44ad',
                'border_color' => '#e0e0e0'
            ),
            'bold' => array(
                'header_bg' => '#2c3e50',
                'header_text' => '#ffffff',
                'header_bg_active' => '#34495e',
                'header_text_active' => '#ffffff',
                'border_color' => '#2c3e50'
            )
        );

        // Merge base colors with style-specific colors
        return array_merge($base_colors, $style_colors[$style] ?? array());
    }

    /**
     * Sanitize accordion data
     *
     * @param array $data Raw accordion data
     * @return array Sanitized accordion data
     */
    public static function sanitize_accordion_data($data) {
        $sanitized = array();

        if (!is_array($data)) {
            return $sanitized;
        }

        // Sanitize style
        $sanitized['style'] = isset($data['style']) ? sanitize_key($data['style']) : 'classic';

        // Sanitize colors
        $sanitized['colors'] = array();
        $default_colors = self::get_default_colors($sanitized['style']);
        
        if (isset($data['colors']) && is_array($data['colors'])) {
            foreach ($default_colors as $key => $default) {
                $color = isset($data['colors'][$key]) ? $data['colors'][$key] : $default;
                $sanitized['colors'][$key] = self::sanitize_color($color, $default);
            }
        } else {
            $sanitized['colors'] = $default_colors;
        }

        // Sanitize sections
        $sanitized['sections'] = array();
        if (isset($data['sections']) && is_array($data['sections'])) {
            foreach ($data['sections'] as $section) {
                if (isset($section['title']) || isset($section['content'])) {
                    $sanitized['sections'][] = array(
                        'title' => isset($section['title']) 
                            ? sanitize_text_field($section['title']) 
                            : '',
                        'content' => isset($section['content']) 
                            ? wp_kses_post($section['content']) 
                            : '',
                        'initial_state' => isset($section['initial_state']) 
                            ? (bool) $section['initial_state'] 
                            : false
                    );
                }
            }
        }

        return $sanitized;
    }

    /**
     * Sanitize color value
     *
     * @param string $color Color value to sanitize
     * @param string $default Default color if invalid
     * @return string Sanitized color
     */
    private static function sanitize_color($color, $default) {
        // Remove any whitespace
        $color = trim($color);

        // Check if it's a valid hex color
        if (preg_match('/^#([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3})$/', $color)) {
            return $color;
        }

        // Check if it's a hex color without #
        if (preg_match('/^([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3})$/', $color)) {
            return '#' . $color;
        }

        return $default;
    }

    /**
     * Generate unique ID for accordion elements
     *
     * @param int $post_id Post ID
     * @param int $index Section index
     * @return string Unique ID
     */
    public static function generate_accordion_id($post_id, $index) {
        return 'aca-' . $post_id . '-' . $index;
    }

    /**
     * Check if current user can manage accordions
     *
     * @return boolean True if user has capability
     */
    public static function can_manage_accordions() {
        return current_user_can('edit_posts');
    }

    /**
     * Convert hex color to RGB
     *
     * @param string $hex Hex color code
     * @return array RGB values
     */
    public static function hex_to_rgb($hex) {
        $hex = str_replace('#', '', $hex);

        if (strlen($hex) === 3) {
            $hex = str_repeat(substr($hex, 0, 1), 2) . 
                   str_repeat(substr($hex, 1, 1), 2) . 
                   str_repeat(substr($hex, 2, 1), 2);
        }

        return array(
            'r' => hexdec(substr($hex, 0, 2)),
            'g' => hexdec(substr($hex, 2, 2)),
            'b' => hexdec(substr($hex, 4, 2))
        );
    }
}