<?php
/**
 * Metabox functionality for the accordion plugin
 *
 * File: includes/class-aca-metabox.php
 * @package AdvancedCustomAccordions
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Class ACA_Metabox
 * Handles all metabox-related functionality
 */
class ACA_Metabox {
    /**
     * Constructor
     */
    public function __construct() {
        add_action('add_meta_boxes', array($this, 'add_meta_boxes'));
        add_action('save_post', array($this, 'save_meta_boxes'), 10, 2);
        add_action('admin_footer', array($this, 'print_templates'));
        add_filter('tiny_mce_before_init', array($this, 'customize_editor'), 10, 2);
    }

    /**
     * Customize TinyMCE editor settings
     */
    public function customize_editor($settings, $editor_id) {
        if (strpos($editor_id, 'aca_section_content_') === 0) {
            // Set up the toolbar buttons
            $settings['toolbar1'] = 'formatselect,bold,italic,bullist,numlist,blockquote,alignleft,aligncenter,alignright,link,wp_more,spellchecker,fullscreen,wp_adv';
            $settings['toolbar2'] = 'strikethrough,hr,forecolor,backcolor,pastetext,removeformat,charmap,outdent,indent,undo,redo,wp_help';
            
            // Ensure TinyMCE keeps line breaks and styling
            $settings['wpautop'] = true;
            $settings['indent'] = true;
            $settings['tadv_noautop'] = false;

            // Show kitchen sink by default
            $settings['wordpress_adv_hidden'] = false;
        }
        return $settings;
    }

    /**
     * Add meta boxes
     */
    public function add_meta_boxes() {
        add_meta_box(
            'aca_accordion_settings',
            __('Accordion Settings', 'advanced-custom-accordions'),
            array($this, 'render_settings_metabox'),
            'aca_accordion',
            'normal',
            'high'
        );

        add_meta_box(
            'aca_accordion_sections',
            __('Accordion Sections', 'advanced-custom-accordions'),
            array($this, 'render_sections_metabox'),
            'aca_accordion',
            'normal',
            'high'
        );

        add_meta_box(
            'aca_accordion_shortcode',
            __('Shortcode', 'advanced-custom-accordions'),
            array($this, 'render_shortcode_metabox'),
            'aca_accordion',
            'side',
            'low'
        );
    }

    /**
     * Render settings metabox
     *
     * @param WP_Post $post Current post object
     */
    public function render_settings_metabox($post) {
        // Add nonce for security
        wp_nonce_field('aca_meta_box_nonce', 'aca_meta_box_nonce');

        // Get saved metadata
        $style = get_post_meta($post->ID, '_aca_style', true);
        $colors = get_post_meta($post->ID, '_aca_colors', true);
        $settings = get_post_meta($post->ID, '_aca_settings', true);

        // Get default values
        $default_style = 'classic';
        $default_colors = ACA_Helper::get_default_colors($style ?: $default_style);
        $default_settings = array(
            'collapse_others' => true,
            'scroll_to_top' => false,
            'initial_open' => -1
        );

        // Merge with defaults
        $colors = wp_parse_args($colors, $default_colors);
        $settings = wp_parse_args($settings, $default_settings);

        // Include settings template
        require_once ACA_PLUGIN_DIR . 'admin/templates/metabox-settings.php';
    }

    /**
     * Render sections metabox
     *
     * @param WP_Post $post Current post object
     */
    public function render_sections_metabox($post) {
        // Get saved sections
        $sections = get_post_meta($post->ID, '_aca_sections', true);
        
        if (!is_array($sections)) {
            $sections = array();
        }

        // Include sections template
        require_once ACA_PLUGIN_DIR . 'admin/templates/metabox-sections.php';
    }

    /**
     * Render shortcode metabox
     *
     * @param WP_Post $post Current post object
     */
    public function render_shortcode_metabox($post) {
        $shortcode = '[accordion id="' . $post->ID . '"]';
        ?>
        <div class="aca-shortcode-wrapper">
            <input type="text" readonly class="aca-shortcode-display" 
                value="<?php echo esc_attr($shortcode); ?>" 
                onclick="this.select()" />
            <p class="description">
                <?php _e('Copy this shortcode and paste it into your post, page, or text widget content to display the accordion.', 'advanced-custom-accordions'); ?>
            </p>
        </div>
        <?php
    }

    /**
     * Save meta box data
     *
     * @param int $post_id Post ID
     * @param WP_Post $post Post object
     */
    public function save_meta_boxes($post_id, $post) {
        // Check if our nonce is set and verify it
        if (!isset($_POST['aca_meta_box_nonce']) || 
            !wp_verify_nonce($_POST['aca_meta_box_nonce'], 'aca_meta_box_nonce')) {
            return;
        }

        // Check the user's permissions
        if (!current_user_can('edit_post', $post_id)) {
            return;
        }

        // Check if this is an autosave
        if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
            return;
        }

        // Check if this is the correct post type
        if ('aca_accordion' !== $post->post_type) {
            return;
        }

        // Save style
        if (isset($_POST['aca_style'])) {
            update_post_meta(
                $post_id,
                '_aca_style',
                sanitize_key($_POST['aca_style'])
            );
        }

        // Save colors
        if (isset($_POST['aca_colors']) && is_array($_POST['aca_colors'])) {
            $colors = array();
            foreach ($_POST['aca_colors'] as $key => $color) {
                $colors[sanitize_key($key)] = sanitize_hex_color($color);
            }
            update_post_meta($post_id, '_aca_colors', $colors);
        }

        // Save settings
        if (isset($_POST['aca_settings']) && is_array($_POST['aca_settings'])) {
            $settings = array(
                'collapse_others' => isset($_POST['aca_settings']['collapse_others']),
                'scroll_to_top' => isset($_POST['aca_settings']['scroll_to_top']),
                'initial_open' => isset($_POST['aca_settings']['initial_open']) ? 
                    intval($_POST['aca_settings']['initial_open']) : -1
            );
            update_post_meta($post_id, '_aca_settings', $settings);
        }

        // Save sections
        if (isset($_POST['aca_sections']) && is_array($_POST['aca_sections'])) {
            $sections = array();
            foreach ($_POST['aca_sections'] as $section) {
                $sections[] = array(
                    'title' => sanitize_text_field($section['title']),
                    'content' => wp_kses_post($section['content']),
                    'initial_state' => isset($section['initial_state'])
                );
            }
            update_post_meta($post_id, '_aca_sections', $sections);
        }
    }

    /**
     * Print JavaScript templates for the accordion interface
     */
    public function print_templates() {
        // Only print on accordion edit screen
        $screen = get_current_screen();
        if (!$screen || 'aca_accordion' !== $screen->post_type) {
            return;
        }
        ?>
        <script type="text/html" id="tmpl-aca-section">
            <div class="aca-section" data-index="{{{data.index}}}">
                <div class="aca-section-header">
                    <span class="aca-drag-handle dashicons dashicons-menu"></span>
                    <div class="aca-section-title">
                        <input type="text" 
                            name="aca_sections[{{{data.index}}}][title]" 
                            value="{{{data.title}}}" 
                            placeholder="<?php esc_attr_e('Section Title', 'advanced-custom-accordions'); ?>" />
                    </div>
                    <div class="aca-section-actions">
                        <label class="aca-toggle-section">
                            <input type="checkbox" 
                                name="aca_sections[{{{data.index}}}][initial_state]" 
                                value="1" 
                                <# if (data.initial_state) { #>checked="checked"<# } #> />
                            <?php esc_html_e('Initially Open', 'advanced-custom-accordions'); ?>
                        </label>
                        <button type="button" class="button aca-remove-section">
                            <span class="dashicons dashicons-trash"></span>
                        </button>
                    </div>
                </div>
                <div class="aca-section-content">
                    <?php
                    wp_editor(
                        '{{{data.content}}}',
                        'aca_section_content_{{{data.index}}}',
                        array(
                            'textarea_name' => 'aca_sections[{{{data.index}}}][content]',
                            'media_buttons' => true,
                            'textarea_rows' => 10,
                            'editor_height' => 200,
                            'editor_class' => 'aca-section-editor',
                            'teeny' => false,
                            'wpautop' => true,
                            'quicktags' => array(
                                'buttons' => 'strong,em,link,block,del,ins,img,ul,ol,li,code,more,close'
                            ),
                            'tinymce' => array(
                                'toolbar1' => 'formatselect,bold,italic,bullist,numlist,blockquote,alignleft,aligncenter,alignright,link,wp_more,spellchecker,fullscreen,wp_adv',
                                'toolbar2' => 'strikethrough,hr,forecolor,backcolor,pastetext,removeformat,charmap,outdent,indent,undo,redo,wp_help',
                                'wordpress_adv_hidden' => false
                            )
                        )
                    );
                    ?>
                </div>
            </div>
        </script>
        <?php
    }
}