<?php
/**
 * Custom Post Type for Accordions
 *
 * @package AdvancedCustomAccordions
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Class ACA_Post_Type
 * Handles the registration and management of the accordion custom post type
 */
class ACA_Post_Type {
    /**
     * Constructor
     */
    public function __construct() {
        // Register post type
        add_action('init', array($this, 'register_post_type'));

        // Add custom columns to post list
        add_filter('manage_aca_accordion_posts_columns', array($this, 'set_custom_columns'));
        add_action('manage_aca_accordion_posts_custom_column', array($this, 'render_custom_columns'), 10, 2);

        // Add sortable columns
        add_filter('manage_edit-aca_accordion_sortable_columns', array($this, 'set_sortable_columns'));

        // Add filter by style
        add_action('restrict_manage_posts', array($this, 'add_style_filter'));
        add_filter('parse_query', array($this, 'filter_accordions_by_style'));
    }

    /**
     * Register the custom post type
     */
    public function register_post_type() {
        $labels = array(
            'name'               => _x('Accordions', 'post type general name', 'advanced-custom-accordions'),
            'singular_name'      => _x('Accordion', 'post type singular name', 'advanced-custom-accordions'),
            'menu_name'          => _x('Accordions', 'admin menu', 'advanced-custom-accordions'),
            'name_admin_bar'     => _x('Accordion', 'add new on admin bar', 'advanced-custom-accordions'),
            'add_new'            => _x('Add New', 'accordion', 'advanced-custom-accordions'),
            'add_new_item'       => __('Add New Accordion', 'advanced-custom-accordions'),
            'new_item'           => __('New Accordion', 'advanced-custom-accordions'),
            'edit_item'          => __('Edit Accordion', 'advanced-custom-accordions'),
            'view_item'          => __('View Accordion', 'advanced-custom-accordions'),
            'all_items'          => __('All Accordions', 'advanced-custom-accordions'),
            'search_items'       => __('Search Accordions', 'advanced-custom-accordions'),
            'parent_item_colon'  => __('Parent Accordions:', 'advanced-custom-accordions'),
            'not_found'          => __('No accordions found.', 'advanced-custom-accordions'),
            'not_found_in_trash' => __('No accordions found in Trash.', 'advanced-custom-accordions')
        );

        $args = array(
            'labels'              => $labels,
            'description'         => __('Custom accordions with multiple styles and options.', 'advanced-custom-accordions'),
            'public'             => false,
            'publicly_queryable' => false,
            'show_ui'            => true,
            'show_in_menu'       => true,
            'query_var'          => true,
            'rewrite'            => false,
            'capability_type'    => 'post',
            'has_archive'        => false,
            'hierarchical'       => false,
            'menu_position'      => 25,
            'menu_icon'          => 'dashicons-list-view',
            'supports'           => array('title'),
            'show_in_rest'       => true,
            'rest_base'          => 'accordions',
            'rest_controller_class' => 'WP_REST_Posts_Controller',
        );

        register_post_type('aca_accordion', $args);
    }

    /**
     * Set custom columns for the accordion list
     *
     * @param array $columns Default columns
     * @return array Modified columns
     */
    public function set_custom_columns($columns) {
        $new_columns = array();
        $new_columns['cb'] = $columns['cb'];
        $new_columns['title'] = __('Title', 'advanced-custom-accordions');
        $new_columns['style'] = __('Style', 'advanced-custom-accordions');
        $new_columns['sections'] = __('Sections', 'advanced-custom-accordions');
        $new_columns['shortcode'] = __('Shortcode', 'advanced-custom-accordions');
        $new_columns['date'] = $columns['date'];

        return $new_columns;
    }

    /**
     * Render custom column content
     *
     * @param string $column Column name
     * @param int $post_id Post ID
     */
    public function render_custom_columns($column, $post_id) {
        switch ($column) {
            case 'style':
                $style = get_post_meta($post_id, '_aca_style', true);
                echo esc_html(ucfirst($style ?: 'classic'));
                break;

            case 'sections':
                $sections = get_post_meta($post_id, '_aca_sections', true);
                echo esc_html(is_array($sections) ? count($sections) : 0);
                break;

            case 'shortcode':
                echo '<input type="text" class="aca-shortcode-display" value="[accordion id=&quot;' . esc_attr($post_id) . '&quot;]" readonly onclick="this.select()" />';
                break;
        }
    }

    /**
     * Set sortable columns
     *
     * @param array $columns Default sortable columns
     * @return array Modified sortable columns
     */
    public function set_sortable_columns($columns) {
        $columns['style'] = 'style';
        $columns['sections'] = 'sections';
        return $columns;
    }

    /**
     * Add style filter dropdown to accordion list
     */
    public function add_style_filter() {
        global $typenow;

        if ('aca_accordion' === $typenow) {
            $current_style = isset($_GET['accordion_style']) ? sanitize_text_field($_GET['accordion_style']) : '';
            $styles = array(
                'classic'  => __('Classic', 'advanced-custom-accordions'),
                'modern'   => __('Modern', 'advanced-custom-accordions'),
                'material' => __('Material', 'advanced-custom-accordions'),
                'elegant'  => __('Elegant', 'advanced-custom-accordions'),
                'bold'     => __('Bold', 'advanced-custom-accordions')
            );

            echo '<select name="accordion_style">';
            echo '<option value="">' . esc_html__('All Styles', 'advanced-custom-accordions') . '</option>';

            foreach ($styles as $value => $label) {
                printf(
                    '<option value="%s" %s>%s</option>',
                    esc_attr($value),
                    selected($current_style, $value, false),
                    esc_html($label)
                );
            }
            echo '</select>';
        }
    }

    /**
     * Filter accordions by style
     *
     * @param WP_Query $query Current query
     */
    public function filter_accordions_by_style($query) {
        global $pagenow;

        if (is_admin() 
            && 'edit.php' === $pagenow 
            && 'aca_accordion' === $query->get('post_type')
            && isset($_GET['accordion_style'])
            && !empty($_GET['accordion_style'])
        ) {
            $query->set('meta_key', '_aca_style');
            $query->set('meta_value', sanitize_text_field($_GET['accordion_style']));
        }
    }
}