<?php
/**
 * Shortcode functionality for the accordion plugin
 *
 * @package AdvancedCustomAccordions
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Class ACA_Shortcode
 * Handles all shortcode-related functionality
 */
class ACA_Shortcode {
    /**
     * Constructor
     */
    public function __construct() {
        add_shortcode('accordion', array($this, 'render_accordion'));
    }

    /**
     * Render accordion shortcode
     *
     * @param array $atts Shortcode attributes
     * @return string Rendered accordion HTML
     */
    public function render_accordion($atts) {
        // Parse attributes
        $atts = shortcode_atts(
            array(
                'id' => 0,
                'style' => '',
                'open_first' => '',
                'collapse_others' => ''
            ),
            $atts,
            'accordion'
        );

        // Check if ID is valid
        $post_id = absint($atts['id']);
        if (!$post_id || 'aca_accordion' !== get_post_type($post_id)) {
            return '';
        }

        // Get accordion data
        $style = get_post_meta($post_id, '_aca_style', true);
        $colors = get_post_meta($post_id, '_aca_colors', true);
        $settings = get_post_meta($post_id, '_aca_settings', true);
        $sections = get_post_meta($post_id, '_aca_sections', true);

        // Override settings with shortcode attributes if specified
        if ('' !== $atts['style']) {
            $style = sanitize_key($atts['style']);
        }
        if ('' !== $atts['open_first']) {
            $settings['initial_open'] = filter_var($atts['open_first'], FILTER_VALIDATE_BOOLEAN) ? 0 : -1;
        }
        if ('' !== $atts['collapse_others']) {
            $settings['collapse_others'] = filter_var($atts['collapse_others'], FILTER_VALIDATE_BOOLEAN);
        }

        // Get default values and merge with custom colors
        if (!$style) {
            $style = 'classic';
        }
        
        $default_colors = ACA_Helper::get_default_colors($style);
        $colors = wp_parse_args($colors ?: array(), $default_colors);
        
        if (!is_array($settings)) {
            $settings = array(
                'collapse_others' => true,
                'scroll_to_top' => false,
                'initial_open' => -1
            );
        }

        // Generate unique identifier for this accordion instance
        $unique_id = 'aca-accordion-' . $post_id . '-' . wp_unique_id();

        // Generate instance-specific CSS
        $instance_css = sprintf(
            '
            #%1$s .aca-trigger {
                background-color: %2$s !important;
                color: %3$s !important;
            }
            #%1$s .aca-section.aca-active .aca-trigger {
                background-color: %4$s !important;
                color: %5$s !important;
            }
            #%1$s .aca-content {
                background-color: %6$s !important;
                color: %7$s !important;
            }
            #%1$s .aca-section {
                border-color: %8$s !important;
            }
            #%1$s .aca-icon::before,
            #%1$s .aca-icon::after {
                background-color: %3$s !important;
            }
            #%1$s .aca-section.aca-active .aca-icon::before,
            #%1$s .aca-section.aca-active .aca-icon::after {
                background-color: %5$s !important;
            }
            #%1$s.aca-style-%9$s .aca-section {
                border-radius: %10$s;
            }
            #%1$s.aca-style-%9$s .aca-trigger {
                border-radius: %11$s;
            }',
            esc_attr($unique_id),
            esc_attr($colors['header_bg']),
            esc_attr($colors['header_text']),
            esc_attr($colors['header_bg_active']),
            esc_attr($colors['header_text_active']),
            esc_attr($colors['content_bg']),
            esc_attr($colors['content_text']),
            esc_attr($colors['border_color']),
            esc_attr($style),
            $style === 'modern' ? '10px' : '6px',
            $style === 'modern' ? '10px' : '6px'
        );

        // Start output buffering
        ob_start();

        // Add container classes
        $classes = array(
            'aca-accordion',
            'aca-style-' . $style,
            $settings['collapse_others'] ? 'aca-collapse-others' : ''
        );

        ?>
        <!-- Accordion Instance Styles -->
        <style type="text/css">
            <?php echo $instance_css; ?>
        </style>
        
        <!-- Accordion Container -->
        <div id="<?php echo esc_attr($unique_id); ?>" 
             class="<?php echo esc_attr(implode(' ', array_filter($classes))); ?>"
             data-settings="<?php echo esc_attr(wp_json_encode($settings)); ?>">
            <?php
            if (is_array($sections)) {
                foreach ($sections as $index => $section) {
                    $section_id = $unique_id . '-section-' . $index;
                    $is_open = ($index === $settings['initial_open']) || 
                              (!empty($section['initial_state']));
                    ?>
                    <div class="aca-section <?php echo $is_open ? 'aca-active' : ''; ?>"
                         id="<?php echo esc_attr($section_id); ?>">
                        <div class="aca-header">
                            <button class="aca-trigger"
                                    aria-expanded="<?php echo $is_open ? 'true' : 'false'; ?>"
                                    aria-controls="<?php echo esc_attr($section_id . '-content'); ?>">
                                <?php echo esc_html($section['title']); ?>
                                <span class="aca-icon"></span>
                            </button>
                        </div>
                        <div id="<?php echo esc_attr($section_id . '-content'); ?>"
                             class="aca-content"
                             role="region"
                             aria-labelledby="<?php echo esc_attr($section_id); ?>"
                             <?php if (!$is_open) : ?>hidden<?php endif; ?>>
                            <div class="aca-content-inner">
                                <?php echo wp_kses_post($section['content']); ?>
                            </div>
                        </div>
                    </div>
                    <?php
                }
            }
            ?>
        </div>

        <?php if (empty($sections)) : ?>
            <p class="aca-no-sections">
                <?php _e('No sections found for this accordion.', 'advanced-custom-accordions'); ?>
            </p>
        <?php endif; ?>

        <?php
        // Get the buffered content
        $output = ob_get_clean();

        // Enqueue necessary scripts and styles
        wp_enqueue_style('aca-accordion-style');
        wp_enqueue_script('aca-accordion-script');

        return $output;
    }
}